#!/bin/bash

cd "$(dirname "$0")"

# Dossiers contenant vos clés
CESIUM_KEYS_DIR="./keys/cesium/"
GCHANGE_KEYS_DIR="./keys/gchange/"

# URL des nœuds
CESIUM_NODE_URL="https://g1.data.e-is.pro"
GCHANGE_NODE_URL="https://data.gchange.fr"

# Nombre de derniers messages à lire
LAST_MSG_COUNT=10

# Vérifiez si VLC ou Kate est ouvert
if pgrep -x "vlc" > /dev/null || pgrep -x "kate" > /dev/null
then
    echo "VLC ou Kate est ouvert, pas de notification"
    exit 0
fi


# Fonction pour lire les messages d'une clef
read_messages() {
    local key_path=$1
    local node_url=$2
    local last_msg_count=$3
    local icon_path=$(realpath $4)

    # Lire les derniers messages au format JSON
    local messages=$(jaklis -k $key_path -n $node_url read -n$last_msg_count --json)

    # Chemin vers le fichier où nous stockons les messages précédents
    local prev_messages_file="prev_messages/$(basename $key_path).json"

    # Lire les messages précédents
    local prev_messages="[]"
    if [ -f $prev_messages_file ]; then
        prev_messages=$(cat $prev_messages_file)
    fi

    # Vérifier si aucun message n'a été reçu
    if [[ $messages == "Aucun message à afficher"* ]]; then
        messages="[]"
    fi

    # Comparer avec les messages précédents et notifier si de nouveaux messages sont détectés
    if [ "$messages" != "$prev_messages" ]; then
        # Identifier les nouveaux messages en comparant les ID des messages
        local new_messages=$(echo "$messages" | jq 'map(select(.id as $in | '"$prev_messages"' | map(.id) | index($in) | not))')

        if [ -n "$new_messages" ]; then
            echo "Nouveaux messages pour la clef $(basename $key_path): $new_messages"
        fi

        # Parcourir chaque nouveau message et créer une notification KDE
        local new_messages_count=$(echo "$new_messages" | jq 'length')
        for (( i=0; i<$new_messages_count; i++ )); do
            local new_message=$(echo "$new_messages" | jq '.['$i']')
            local title=$(echo "$new_message" | jq -r '.title')
            local content=$(echo "$new_message" | jq -r '.content')
            local timestamp=$(echo "$new_message" | jq -r '.date')
            local date=$(date -d "@$timestamp")

            # Obtenir le nom de la clef formaté
            local key_name=$(basename $key_path .dunikey | sed 's/_/ /g')

            # Envoyer une notification KDE avec le titre et le contenu du message
            kdialog --icon $icon_path --title "[$date][$key_name] $title" --passivepopup "$content" 300
        done
    fi

    # Stocker les messages actuels pour la prochaine vérification
    echo "$messages" > $prev_messages_file
}

# Lire les messages pour toutes les clefs Cesium
for key_path in $CESIUM_KEYS_DIR*.dunikey; do
    read_messages $key_path $CESIUM_NODE_URL $LAST_MSG_COUNT "./icons/Cesium.svg"
done

# Lire les messages pour toutes les clefs Gchange
for key_path in $GCHANGE_KEYS_DIR*.dunikey; do
    read_messages $key_path $GCHANGE_NODE_URL $LAST_MSG_COUNT "./icons/gchange.png"
done
