#!/bin/bash

cd "$(dirname "$0")"

# Dossiers contenant vos clés
G1_KEYS_DIR="./keys/g1/"

# Nombre de dernières transactions à lire
LAST_TX_COUNT=10

# Vérifiez si VLC ou Kate est ouvert
if pgrep -x "vlc" > /dev/null || pgrep -x "kate" > /dev/null
then
    echo "VLC ou Kate est ouvert, pas de notification"
    exit 0
fi

# Fonction pour lire l'historique des transactions d'une clé publique
read_transactions() {
    local pubkey_file=$1
    local last_tx_count=$2
    local icon_path=$(realpath $3)
    local gva_url=$4

    # Lire la clé publique du fichier
    local pubkey=$(cat $pubkey_file | tr -d "[:space:]")

    # Lire les dernières transactions au format JSON
    local transactions=$(jaklis --node $gva_url history -p $pubkey -n$last_tx_count --json)

    # Chemin vers le fichier où nous stockons les transactions précédentes
    local prev_transactions_file="prev_transactions/$(basename $pubkey_file .txt).json"

    # Si le fichier des transactions précédentes n'existe pas, on le crée
    if [ ! -f $prev_transactions_file ]; then
        echo "[]" > $prev_transactions_file
    fi

    # Lire les transactions précédentes
    local prev_transactions=$(cat $prev_transactions_file)

    # Vérifiez si le fichier est vide et, dans ce cas, initialisez prev_transactions à un tableau vide
    if [ -z "$prev_transactions" ]; then
        prev_transactions="[]"
        echo "[]" > $prev_transactions_file
    fi

    # Comparer avec les transactions précédentes et notifier si de nouvelles transactions sont détectées
    if [ ! -z $(echo "$transactions" | tr -d "[:space:]") ] && [ "$transactions" != "$prev_transactions" ]; then
        # Identifier les nouvelles transactions en comparant les ID des transactions
        local new_transactions=$(echo "$transactions" | jq 'map(select(.hash as $in | '"$prev_transactions"' | map(.hash) | index($in) | not))')

        if [ -n "$new_transactions" ]; then
            echo "Nouvelles transactions pour la clef $(basename $pubkey_file .txt): $new_transactions"
        fi

        # Parcourir chaque nouvelle transaction et créer une notification KDE
        local new_transactions_count=$(echo "$new_transactions" | jq 'length')
        for (( i=0; i<$new_transactions_count; i++ )); do
            local new_transaction=$(echo "$new_transactions" | jq '.['$i']')
            local amount=$(echo "$new_transaction" | jq -r '.amount')
            local comment=$(echo "$new_transaction" | jq -r '.comment')
            local timestamp=$(echo "$new_transaction" | jq -r '.date')
            local date=$(date -d "@$timestamp")

            # Obtenir le nom de la clef formaté
            local key_name=$(basename $pubkey_file .txt | sed 's/_/ /g')

            # Envoyer une notification KDE avec le montant et le commentaire de la transaction
            kdialog --icon $icon_path --title "[$date][$key_name] Nouveau versement de $amount Ğ1" --passivepopup "$comment" 300
        done

        # Stocker les transactions actuelles pour la prochaine vérification
        echo "$transactions" > $prev_transactions_file
    else
        echo ""
        echo "Pas de nouvelle transaction."
        echo ""
    fi
}


GVA_URLS=(
    "https://duniter.pini.fr/gva"
    "https://g1.asycn.io/gva"
    "https://fania.g1server.net/gva"
    "https://g1.brussels.ovh/gva"
    "https://g1.cgeek.fr/gva"
)

i=0

# Lire les transactions pour toutes les clefs G1
for pubkey_file in $G1_KEYS_DIR*.txt; do

    echo "on node ${GVA_URLS[$i]}"

    read_transactions $pubkey_file $LAST_TX_COUNT "./icons/G.svg" ${GVA_URLS[$i]}

    sleep 5s
    i=$((i+1))
    if [ $i -eq ${#GVA_URLS[@]} ]; then
        i=0
    fi
done
